/*
   Copyright 1999 by CodeFab, Inc.   All rights reserved.

   This notice may not be removed from this source code.
   The use and distribution of this software is governed by the
   terms of the MiscKit license agreement.  Refer to the license
   document included with the MiscKit distribution for the terms.
   Details of the license agreement may be found at
   www.misckit.com or within the MiscKit distribution.

   There may be more information about this software on
   www.codefab.com.  Send queries to ask_codefab@codefab.com.
*/

@interface NSObject (CFRLoggingExtensions)
/*"
 * Logging Methods (cover methods)
"*/
#if 0
- (void)logWithFormat:(NSString *)aFormat, ...;
- (void)logWithFormat:(NSString *)aFormat arguments:(va_list)argList;
#endif

- (void)logMethod: (SEL) aMethod withFormat:(NSString *)aFormat, ...;
- (void)logMethod: (SEL) aMethod withFormat:(NSString *)aFormat arguments:(va_list)argList;

- (void)logMethod:(SEL)aMethod
         ofObject:(id)anObject
       withFormat:(NSString *)aFormat, ...;
- (void)logMethod:(SEL)aMethod
         ofObject:(id)anObject
       withFormat:(NSString *)aFormat
        arguments:(va_list)argList;

+ (void)logWithFormat:(NSString *)aFormat, ...;
+ (void)logWithFormat:(NSString *)aFormat arguments:(va_list)argList;

+ (void)logMethod: (SEL) aMethod withFormat:(NSString *)aFormat, ...;
+ (void)logMethod: (SEL) aMethod
       withFormat:(NSString *)aFormat
        arguments:(va_list)argList;

+ (void)logMethod:(SEL)aMethod
         ofObject:(id)anObject
       withFormat:(NSString *)aFormat, ...;
+ (void)logMethod:(SEL)aMethod
         ofObject:(id)anObject
       withFormat:(NSString *)aFormat
        arguments:(va_list)argList;

/*"
 * Logging Message Generation (cover methods)
"*/
- (NSString *)logStringWithFormat:(NSString *)aFormat, ...;
- (NSString *)logStringWithFormat:(NSString *)aFormat
                        arguments:(va_list)argList;

- (NSString *)logStringForMethod: (SEL) aMethod
                      withFormat:(NSString *)aFormat, ...;
- (NSString *)logStringForMethod: (SEL) aMethod
                      withFormat:(NSString *)aFormat
                       arguments:(va_list)argList;

- (NSString *)logStringForMethod:(SEL)aMethod
                        ofObject:(id)anObject
                      withFormat:(NSString *)aFormat, ...;
- (NSString *)logStringForMethod:(SEL)aMethod
                        ofObject:(id)anObject
                      withFormat:(NSString *)aFormat
                       arguments:(va_list)argList;

+ (NSString *)logStringWithFormat:(NSString *)aFormat, ...;
+ (NSString *)logStringWithFormat:(NSString *)aFormat
                        arguments:(va_list)argList;

+ (NSString *)logStringForMethod: (SEL) aMethod
                      withFormat:(NSString *)aFormat, ...;
+ (NSString *)logStringForMethod: (SEL) aMethod
                      withFormat:(NSString *)aFormat
                       arguments:(va_list)argList;

+ (NSString *)logStringForMethod:(SEL)aMethod
                        ofObject:(id)anObject
                      withFormat:(NSString *)aFormat, ...;
+ (NSString *)logStringForMethod:(SEL)aMethod
                        ofObject:(id)anObject
                      withFormat:(NSString *)aFormat
                       arguments:(va_list)argList;

/*"
 * Logging Configuration & Control
"*/
+ (void)setLoggingEnabbled:(BOOL) aFlag;
+ (BOOL)loggingEnabled;
+ (void)setLoggingFileHandle: (NSFileHandle *) aHandle;
+ (NSFileHandle *)loggingFileHandle;

/*"
 * Logging Generation & Output Methods
"*/
+ (void)reallyLogMethod:(SEL)aMethod
               ofObject:(id)anObject
             withFormat:(NSString *) aFormat
              arguments:(va_list)argList
       showSelectorInfo:(BOOL) aFlag;
+ (void)logMethod:(SEL)aMethod
         ofObject:(id)anObject
       withFormat:(NSString *)aFormat
        arguments:(va_list)argList
 showSelectorInfo:(BOOL) aFlag;
+ (NSString *)logStringForMethod:(SEL)aMethod
                        ofObject:(id)anObject
                      withFormat:(NSString *)aFormat
                       arguments:(va_list)argList
                showSelectorInfo:(BOOL) aFlag;
+ (NSString *) canonicalNameForClass: (id)theObject;
+ (NSString *) methodLabelForInstance: (id) anObject
                          andSelector: (SEL) aSelector;

/*"
 * Convenient & Quick Termination
"*/
+ (void) exit: (NSString *) msg;
- (void) exit: (NSString *) msg;

/*"
 *  Interval Timer Utility Methods
"*/
- (void) resetIntervalTimerBase;
- (NSDate *) intervalTimerBase;
- (NSTimeInterval) timeIntervalSinceIntervalTimerBase;
- (NSString *) intervalTimerLoggingFormat;
- (void) setIntervalTimerLoggingFormat: (NSString *) aFormat;
- (NSString *) stringFromTimerIntervalSinceBase;
- (void) logTimeIntervalForMethod: (SEL) aMethod withFormat: (NSString *) aFormat, ...;
@end

@interface NSObject (CanonicalNameDelegatedAPI)
- (NSString *) dfobjc_canonicalName;
+ (NSString *) dfobjc_canonicalName;
- (NSString *) name;
@end
