/*
 File: MsshScriptedModule.m

   Original Author: bbum

   Copyright 1999 by CodeFab, Inc.   All rights reserved.

   This notice may not be removed from this source code.
   The use and distribution of this software is governed by the
   terms of the MiscKit license agreement.  Refer to the license
   document included with the MiscKit distribution for the terms.
   Details of the license agreement may be found at
   www.misckit.com or within the MiscKit distribution.

   There may be more information about this software on
   www.codefab.com.  Send queries to ask_codefab@codefab.com.
*/

#import <Foundation/Foundation.h>
#import <EOControl/EOControl.h>
#import <EOAccess/EOAccess.h>
#import <WebObjects/WebObjects.h>

#import "NMSScope.h"
#import "NMSDebugger.h"
#import "NMSScriptFlavor.h"
#import "NMSScriptedObject.h"

#import "CodeFabSupport.h"

#import "Mssh.h"

@implementation MsshScriptedModule
static NSMutableDictionary *moduleDictionary = nil;
static NSMutableDictionary *searchBundles = nil;
static NSMutableArray *searchPaths = nil;
static BOOL hasInitialized = NO;

+ (void)initializeSearchPaths;
{
    NSArray *additionalPaths;

    if (searchPaths != nil)
        [searchPaths release];
    searchPaths = [[NSMutableArray array] retain];

    if (searchBundles != nil)
        [searchBundles release];
    searchBundles = [[NSMutableDictionary dictionary] retain];

    [self addSearchBundle: [MsshController msshFrameworkBundle] searchFirst: NO];

    // load defaults module now so we pick up any command specific defaults!
    [MsshScriptedModule scriptedModuleNamed: @"MsshScriptedDefaultsModule"];

    // check defaults database
    additionalPaths = [[NSUserDefaults standardUserDefaults] objectForKey: @"ScriptedModuleSearchPaths"];
    if (additionalPaths != nil) {
        NSEnumerator *pathEnumerator = [additionalPaths reverseObjectEnumerator];
        NSString *nextPath;

        while ( (nextPath = [pathEnumerator nextObject]) != nil )
            [self addSearchPath: nextPath searchFirst: YES];
    }
}

+ (void) initializeMsshScriptedModule
{
    hasInitialized = YES;

    [self initializeSearchPaths];
    
    if (moduleDictionary != nil)
        [moduleDictionary release];
    
    moduleDictionary = [[NSMutableDictionary dictionary] retain];
}

+ (void) addSearchPath: (NSString *) aPath searchFirst: (BOOL) aFlag;
{
    if (hasInitialized == NO) [self initializeMsshScriptedModule];

    if (aPath == nil)
        return;

    aPath = [aPath stringByStandardizingPath];
    
    if (aFlag == YES)
        [searchPaths insertObject: aPath atIndex: 0];
    else
        [searchPaths addObject: aPath];
}

+ (void) addSearchBundle: (NSBundle *) aBundle searchFirst: (BOOL) aFlag;
{
    NSString *bundlePath;
    
    if (hasInitialized == NO) [self initializeMsshScriptedModule];

    if (aBundle == nil)
        return;

    bundlePath = [aBundle bundlePath];
    
    [searchBundles setObject: aBundle forKey: bundlePath];

    if (aFlag == YES)
        [searchPaths insertObject: bundlePath atIndex: 0];
    else
        [searchPaths addObject: bundlePath];
}

+ (NSMutableArray *) moduleSearchPaths;
{
    if (hasInitialized == NO) [self initializeMsshScriptedModule];
    return searchPaths;
}

+ (MsshScriptedModule *) scriptedModuleNamed: (NSString *) aName;
{
    MsshScriptedModule *module;

    if (hasInitialized == NO) [self initializeMsshScriptedModule];

    module = [moduleDictionary objectForKey: aName];
    if (module == nil) {
        NSBundle *searchBundle;
        NSString *searchPath;
        NSEnumerator *pathsEnumerator;
        NSString *pathToModule;
        Class moduleClass;

        pathsEnumerator = [searchPaths objectEnumerator];
        while ( (searchPath = [pathsEnumerator nextObject]) != nil ) {
            searchBundle = [searchBundles objectForKey: searchPath];
            if (searchBundle == nil) {
                searchBundle = [NSBundle bundleWithPath: searchPath];
                if (searchBundle == nil)
                    continue; // go to next path
                [searchBundles setObject: searchBundle forKey: searchPath];
            }

            pathToModule = [searchBundle pathForResource: aName ofType: @"wos"];
            if (pathToModule == nil)
                continue; // try next path/bundle

            moduleClass = [MsshController importScriptedClassForPath: pathToModule];
            module = [[moduleClass alloc] init];

            if (module == nil)
                [NSException raise: NSInternalInconsistencyException
                            format: @"%@: Failed to load or allocate module at path '%@'.", CFRMETHODLABEL, pathToModule];

            [moduleDictionary setObject: module forKey: aName];
            break; // 
        }
    }

    if (module == nil)
        [NSException raise: NSInternalInconsistencyException
                    format: @"%@: Failed to find module named'%@'.", CFRMETHODLABEL, aName];
    
    return module;
}

@end