/*
 File: NSScanner+ScriptableAPI.h

   Original Author: bbum

   Copyright 1999 by CodeFab, Inc.   All rights reserved.

   This notice may not be removed from this source code.
   The use and distribution of this software is governed by the
   terms of the MiscKit license agreement.  Refer to the license
   document included with the MiscKit distribution for the terms.
   Details of the license agreement may be found at
   www.misckit.com or within the MiscKit distribution.

   There may be more information about this software on
   www.codefab.com.  Send queries to ask_codefab@codefab.com.
*/
#import <Foundation/Foundation.h>
#import <EOControl/EOControl.h>
#import <WebObjects/WebObjects.h>

#import "Mssh.h"

#import "NSScanner+ScriptableAPI.h"

NSString *MSSHScannerValueKey = @"MSSH Scanner Value Key *** DEPRECATED USE MSSHSScriptableAPIValueKey ***";

@implementation NSScanner (ScriptableAPI)
- (BOOL) scanIntIntoDictionary: (NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanInt: NULL];
    else {
        int scannedValue;
        BOOL returnValue;

        returnValue = [self scanInt: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        [aDictionary setObject: [NSNumber numberWithInt: scannedValue] forKey: MSSHScannerValueKey]; // deprecated
        [aDictionary setObject: [NSNumber numberWithInt: scannedValue] forKey: MSSHSScriptableAPIValueKey];

        return returnValue;
    }
}

- (BOOL) scanHexIntIntoDictionary: (NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanHexInt: NULL];
    else {
        unsigned scannedValue;
        BOOL returnValue;

        returnValue = [self scanHexInt: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        [aDictionary setObject: [NSNumber numberWithUnsignedInt: scannedValue] forKey: MSSHScannerValueKey]; // deprecated
        [aDictionary setObject: [NSNumber numberWithUnsignedInt: scannedValue] forKey: MSSHSScriptableAPIValueKey];
        
        return returnValue;
    }
}

- (BOOL) scanLongLongIntoDictionary: (NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanLongLong: NULL];
    else {
        long long scannedValue;
        BOOL returnValue;

        returnValue = [self scanLongLong: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        [aDictionary setObject: [NSNumber numberWithLongLong: scannedValue] forKey: MSSHScannerValueKey]; // deprecated
        [aDictionary setObject: [NSNumber numberWithLongLong: scannedValue] forKey: MSSHSScriptableAPIValueKey];
        
        return returnValue;
    }
}

- (BOOL) scanFloatIntoDictionary: (NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanFloat: NULL];
    else {
        float scannedValue;
        BOOL returnValue;

        returnValue = [self scanFloat: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        [aDictionary setObject: [NSNumber numberWithFloat: scannedValue] forKey: MSSHScannerValueKey]; // deprecated
        [aDictionary setObject: [NSNumber numberWithFloat: scannedValue] forKey: MSSHSScriptableAPIValueKey];

        return returnValue;
    }
}

- (BOOL) scanDoubleIntoDictionary: (NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanDouble: NULL];
    else {
        double scannedValue;
        BOOL returnValue;

        returnValue = [self scanDouble: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        [aDictionary setObject: [NSNumber numberWithDouble: scannedValue] forKey: MSSHScannerValueKey]; // deprecated
        [aDictionary setObject: [NSNumber numberWithDouble: scannedValue] forKey: MSSHSScriptableAPIValueKey];

        return returnValue;
    }
}

- (BOOL) scanCharactersFromSet:(NSCharacterSet *)set intoDictionary:(NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanCharactersFromSet:set intoString: NULL];
    else {
        NSString *scannedValue;
        BOOL returnValue;

        returnValue = [self scanCharactersFromSet:set intoString: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        if (scannedValue != nil) {
            [aDictionary setObject: scannedValue forKey: MSSHScannerValueKey]; // deprecated
            [aDictionary setObject: scannedValue forKey: MSSHSScriptableAPIValueKey];
        }

        return returnValue;
    }
}

- (BOOL) scanString:(NSString *)string intoDictionary:(NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanString:string intoString: NULL];
    else {
        NSString *scannedValue;
        BOOL returnValue;

        returnValue = [self scanString:string intoString: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        if (scannedValue != nil) {
            [aDictionary setObject: scannedValue forKey: MSSHScannerValueKey];
            [aDictionary setObject: scannedValue forKey: MSSHSScriptableAPIValueKey]; // deprecated
        }

        return returnValue;
    }
}

- (BOOL) scanUpToString:(NSString *)string intoDictionary:(NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanUpToString:string intoString: NULL];
    else {
        NSString *scannedValue;
        BOOL returnValue;

        returnValue = [self scanUpToString:string intoString: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        if (scannedValue != nil) {
            [aDictionary setObject: scannedValue forKey: MSSHScannerValueKey]; // deprecated
            [aDictionary setObject: scannedValue forKey: MSSHSScriptableAPIValueKey];
        }
        return returnValue;
    }
}

- (BOOL) scanUpToCharactersFromSet:(NSCharacterSet *)set intoDictionary:(NSMutableDictionary *) aDictionary;
{
    if (aDictionary == nil)
        return [self scanUpToCharactersFromSet:set intoString: NULL];
    else {
        NSString *scannedValue;
        BOOL returnValue;

        returnValue = [self scanUpToCharactersFromSet:set intoString: &scannedValue];

        [aDictionary removeObjectForKey: MSSHScannerValueKey];
        [aDictionary removeObjectForKey: MSSHSScriptableAPIValueKey];
        if (scannedValue != nil) {
            [aDictionary setObject: scannedValue forKey: MSSHScannerValueKey]; // deprecated
            [aDictionary setObject: scannedValue forKey: MSSHSScriptableAPIValueKey];
        }

        return returnValue;
    }
}
@end
